OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Osadzona wiadomość %s",
    "Important mail" : "Ważna poczta",
    "No message found yet" : "Nie znaleziono jeszcze wiadomości",
    "Set up an account" : "Załóż konto",
    "Unread mail" : "Nieprzeczytana wiadomość",
    "Important" : "Ważne",
    "Work" : "Praca",
    "Personal" : "Osobiste",
    "To Do" : "Do zrobienia",
    "Later" : "Później",
    "Mail" : "Poczta",
    "You are reaching your mailbox quota limit for {account_email}" : "Osiągnięto limit skrzynki pocztowej dla {account_email}",
    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "Obecnie używasz {percentage} przestrzeni dyskowej skrzynki pocztowej. Zrób trochę miejsca, usuwając niepotrzebne wiadomości e-mail.",
    "Mails" : "E-maile",
    "💌 A mail app for Nextcloud" : "💌 Aplikacja poczty dla Nextcloud",
    "Your session has expired. The page will be reloaded." : "Twoja sesja wygasła. Strona zostanie ponownie załadowana.",
    "Drafts are saved in:" : "Wersje robocze są zapisywane w:",
    "Sent messages are saved in:" : "Wysłane wiadomości są zapisywane w:",
    "Deleted messages are moved in:" : "Usunięte wiadomości są przenoszone do:",
    "Archived messages are moved in:" : "Zarchiwizowane wiadomości są przenoszone w:",
    "Snoozed messages are moved in:" : "Odłożone wiadomości są przenoszone:",
    "Junk messages are saved in:" : "Wiadomości-śmieci są zapisywane w:",
    "Auto" : "Automatycznie",
    "Name" : "Nazwa",
    "Mail address" : "Adres mailowy",
    "name@example.org" : "nazwa@przyład.org",
    "Please enter an email of the format name@example.com" : "Podaj swój adres mailowy w formacie nazwa@przykład.com",
    "Password" : "Hasło",
    "Manual" : "Ręcznie",
    "IMAP Settings" : "Ustawienia IMAP",
    "IMAP Host" : "Host IMAP",
    "IMAP Security" : "Zabezpieczenia IMAP",
    "None" : "Brak",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Port IMAP",
    "IMAP User" : "Użytkownik IMAP",
    "IMAP Password" : "Hasło IMAP",
    "SMTP Settings" : "Ustawienia SMTP",
    "SMTP Host" : "Host SMTP",
    "SMTP Security" : "Zabezpieczenia SMTP",
    "SMTP Port" : "Port SMTP",
    "SMTP User" : "Użytkownik SMTP",
    "SMTP Password" : "Hasło SMTP",
    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "Aby konto Google mogło współpracować z tą aplikacją, musisz włączyć uwierzytelnianie dwuskładnikowe dla Google i wygenerować hasło do aplikacji.",
    "Connecting" : "Łączenie",
    "Reconnect Google account" : "Połącz ponownie konto Google",
    "Sign in with Google" : "Zaloguj się przez Google",
    "Save" : "Zapisz",
    "Connect" : "Połącz",
    "Looking up configuration" : "Wyszukiwanie konfiguracji",
    "Checking mail host connectivity" : "Sprawdzanie połączenia z hostem poczty",
    "Configuration discovery failed. Please use the manual settings" : "Wykrywanie konfiguracji nie powiodło się. Użyj ustawień ręcznych",
    "Password required" : "Wymagane hasło",
    "Testing authentication" : "Testowanie uwierzytelnienia",
    "Awaiting user consent" : "Oczekiwanie na zgodę użytkownika",
    "Loading account" : "Wczytywanie konta",
    "Account updated" : "Konto zaktualizowane",
    "IMAP server is not reachable" : "Serwer IMAP jest nieosiągalny",
    "SMTP server is not reachable" : "Serwer SMTP jest nieosiągalny",
    "IMAP username or password is wrong" : "Nieprawidłowa nazwa użytkownika lub hasło IMAP",
    "SMTP username or password is wrong" : "Nieprawidłowa nazwa użytkownika lub hasło SMTP",
    "IMAP connection failed" : "Połączenie IMAP nie powiodło się",
    "SMTP connection failed" : "Połączenie SMTP nie powiodło się",
    "Authorization pop-up closed" : "Wyskakujące okienko autoryzacji zostało zamknięte",
    "Configuration discovery temporarily not available. Please try again later." : "Wykrywanie konfiguracji tymczasowo niedostępne. Spróbuj ponownie później.",
    "There was an error while setting up your account" : "Wystąpił błąd podczas zakładania konta",
    "Account settings" : "Ustawienia konta",
    "Aliases" : "Aliasy",
    "Signature" : "Podpis",
    "A signature is added to the text of new messages and replies." : "Podpis jest dodawany do tekstu nowych wiadomości i odpowiedzi.",
    "Writing mode" : "Tryb pisania",
    "Preferred writing mode for new messages and replies." : "Preferowany tryb pisania dla nowych wiadomości i odpowiedzi.",
    "Default folders" : "Katalogi domyślne",
    "The folders to use for drafts, sent messages, deleted messages, archived messages and junk messages." : "Katalogi używane dla wersji roboczych, wysłanych wiadomości, usuniętych wiadomości, zarchiwizowanych wiadomości i wiadomości-śmieci.",
    "Automatic trash deletion" : "Automatyczne usuwanie śmieci",
    "Days after which messages in Trash will automatically be deleted:" : "Dni, po których wiadomości w Koszu zostaną automatycznie usunięte:",
    "Autoresponder" : "Automatyczna wiadomość zwrotna",
    "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Automatyczna odpowiedź na przychodzące wiadomości. Jeśli ktoś wyśle Tobie kilka wiadomości, ta automatyczna odpowiedź będzie wysyłana co najwyżej raz na 4 dni.",
    "Please connect to a sieve server first." : "Najpierw połącz się z serwerem Sieve.",
    "Filters" : "Filtry",
    "Mail server" : "Serwer poczty",
    "Update alias" : "Zaktualizuj alias",
    "Rename alias" : "Zmień nazwę aliasu",
    "Show update alias form" : "Pokaż formularz aktualizacji aliasu",
    "Delete alias" : "Usuń alias",
    "Go back" : "Wstecz",
    "Change name" : "Zmień nazwę",
    "Email address" : "Adres e-mail",
    "Add alias" : "Dodaj alias",
    "Create alias" : "Utwórz alias",
    "Cancel" : "Anuluj",
    "Mail settings" : "Ustawienia Poczty",
    "Accounts" : "Konta",
    "Add mail account" : "Dodaj konto e-mail",
    "General" : "Ogólne",
    "Layout" : "Wygląd",
    "List" : "Lista",
    "Sorting" : "Sortuj",
    "Newest" : "Najnowsza",
    "Oldest" : "Najstarsza",
    "Reply text position" : "Pozycja tekstu odpowiedzi",
    "Gravatar settings" : "Ustawienia Gravatara",
    "Use Gravatar and favicon avatars" : "Używaj awatarów Gravatar i favicon",
    "Register as application for mail links" : "Zarejestruj się jako aplikacja do linków pocztowych",
    "Register" : "Zarejestruj się",
    "Data collection consent" : "Zgoda na zbieranie danych",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Zezwól aplikacji na zbieranie danych o Twoich interakcjach. Na podstawie tych danych aplikacja dostosuje się do Twoich preferencji. Dane będą przechowywane tylko lokalnie.",
    "Trusted senders" : "Zaufani nadawcy",
    "Manage S/MIME certificates" : "Zarządzaj certyfikatami S/MIME",
    "Looking for a way to encrypt your emails?" : "Szukasz sposobu na szyfrowanie wiadomości e-mail?",
    "Keyboard shortcuts" : "Skróty klawiaturowe",
    "Compose new message" : "Napisz nową wiadomość",
    "Newer message" : "Nowsza wiadomość",
    "Older message" : "Starsza wiadomość",
    "Toggle star" : "Oznacz gwiazdką",
    "Toggle unread" : "Oznacz jako nieprzeczytane",
    "Archive" : "Archiwizuj",
    "Delete" : "Usuń",
    "Search" : "Szukaj",
    "Send" : "Wyślij",
    "Refresh" : "Odśwież",
    "Activate" : "Aktywuj",
    "Put my text to the bottom of a reply instead of on top of it." : "Umieść mój tekst na dole odpowiedzi, zamiast nad nią.",
    "Could not update preference" : "Nie udało się zaktualizować preferencji",
    "Certificate updated" : "Aktualizacja certyfikatu",
    "From" : "Od",
    "Select account" : "Wybierz konto",
    "To" : "Do",
    "Select recipient" : "Wybierz odbiorcę",
    "Contact or email address …" : "Kontakt lub adres e-mail…",
    "Cc" : "DW",
    "Bcc" : "UDW",
    "Subject" : "Temat",
    "Subject …" : "Temat…",
    "This message came from a noreply address so your reply will probably not be read." : "Ta wiadomość przyszła z adresu noreply, więc Twoja odpowiedź prawdopodobnie nie zostanie odczytana.",
    "The following recipients do not have a PGP key: {recipients}." : "Następujący odbiorcy nie mają klucza PGP: {recipients}.",
    "Write message …" : "Wpisz wiadomość…",
    "Saving draft …" : "Zapisywanie wersji roboczej…",
    "Error saving draft" : "Błąd podczas zapisywania wersji roboczej",
    "Draft saved" : "Zapisano wersję roboczą",
    "Save draft" : "Zapisz wersję roboczą",
    "Discard & close draft" : "Odrzuć i zamknij wersję roboczą",
    "Enable formatting" : "Włącz formatowanie",
    "Disable formatting" : "Wyłącz formatowanie",
    "Upload attachment" : "Dodaj załącznik",
    "Add attachment from Files" : "Dodaj załącznik z Plików",
    "Smart picker" : "Inteligentna selekcja",
    "Send later" : "Wyślij później",
    "Request a read receipt" : "Poproś o potwierdzenie przeczytania",
    "Encrypt message with Mailvelope" : "Zaszyfruj wiadomość za pomocą Mailvelope",
    "Send now" : "Wyślij teraz",
    "Tomorrow morning" : "Jutro rano",
    "Tomorrow afternoon" : "Jutro popołudniu",
    "Monday morning" : "W poniedziałek rano",
    "Custom date and time" : "Własna data i godzina",
    "Enter a date" : "Wpisz datę",
    "Message {id} could not be found" : "Nie można znaleźć wiadomości {id}",
    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Wszelkie istniejące formatowanie (na przykład pogrubienie, kursywa, podkreślenie lub obrazy w tekście) zostaną usunięte.",
    "Turn off formatting" : "Wyłącz formatowanie",
    "Turn off and remove formatting" : "Wyłącz i usuń formatowanie",
    "Keep formatting" : "Zachowaj formatowanie",
    "Choose a file to add as attachment" : "Wybierz plik, aby dodać jako załącznik",
    "Choose a file to share as a link" : "Wybierz plik do udostępnienia przez link",
    "Choose" : "Wybierz",
    "_{count} attachment_::_{count} attachments_" : ["{count} załącznik","{count} załączniki","{count} załączników","{count} załączników"],
    "Untitled message" : "Wiadomość bez tytułu",
    "Confirm" : "Potwierdź",
    "Plain text" : "Zwykły tekst",
    "Rich text" : "Tekst sformatowany",
    "No messages in this mailbox" : "Brak wiadomości w skrzynce pocztowej",
    "No messages" : "Brak wiadomości",
    "Draft: " : "Wersja robocza:",
    "Encrypted message" : "Zaszyfrowana wiadomość",
    "This message is unread" : "Ta wiadomość jest nieprzeczytana",
    "Unfavorite" : "Nie ulubione",
    "Favorite" : "Ulubione",
    "Unread" : "Nieprzeczytane",
    "Read" : "Przeczytane",
    "Unimportant" : "Nieważne",
    "Mark not spam" : "Nie spam",
    "Mark as spam" : "Oznacz jako spam",
    "Edit tags" : "Edytuj etykiety",
    "Move thread" : "Przenieś wątek",
    "Archive thread" : "Wątek archiwalny",
    "Delete thread" : "Usuń wątek",
    "More actions" : "Więcej akcji",
    "Back" : "Poprzednia",
    "Edit as new message" : "Edytuj jako nową wiadomość",
    "Create event" : "Utwórz wydarzenie",
    "Create task" : "Utwórz zadanie",
    "Download message" : "Pobierz wiadomość",
    "Blind copy recipients only" : "Tylko dla niewidocznych kopii",
    "No subject" : "Brak tematu",
    "Set reminder for later today" : "Ustaw przypomnienie na dzisiaj na późniejszy czas",
    "Set reminder for tomorrow" : "Ustaw przypomnienie na jutro",
    "Set reminder for this weekend" : "Ustaw przypomnienie na ten weekend",
    "Set reminder for next week" : "Ustaw przypomnienie na przyszły tydzień",
    "No trash mailbox configured" : "Nie skonfigurowano skrzynki pocztowej dla kosza",
    "Could not delete message" : "Nie udało się usunąć wiadomości",
    "Could not archive message" : "Nie udało się zarchiwizować wiadomości",
    "Load more" : "Wczytaj więcej",
    "_Mark {number} read_::_Mark {number} read_" : ["Oznacz {number} jako przeczytana","Oznacz {number} jako przeczytane","Oznacz {number} jako przeczytane","Oznacz {number} jako przeczytane"],
    "_Mark {number} unread_::_Mark {number} unread_" : ["Oznacz {number} jako nieprzeczytana","Oznacz {number} jako nieprzeczytane","Oznacz {number} jako nieprzeczytane","Oznacz {number} jako nieprzeczytane"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["Oznacz {number} jako ważne","Oznacz {number} jako ważne","Oznacz {number} jako ważne","Oznacz {number} jako ważne"],
    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Oznacz {number} jako nieważne","Oznacz {number} jako nieważne","Oznacz {number} jako nieważne","Oznacz {number} jako nieważne"],
    "_Unfavorite {number}_::_Unfavorite {number}_" : ["Nie ulubiona {number}","Nie ulubione {number}","Nie ulubionych {number}","Nie ulubionych {number}"],
    "_Favorite {number}_::_Favorite {number}_" : ["Ulubiona {number}","Ulubione {number}","Ulubionych {number}","Ulubionych {number}"],
    "_Unselect {number}_::_Unselect {number}_" : ["Odznacz {number}","Odznacz {number}","Odznacz {number}","Odznacz {number}"],
    "_Mark {number} as spam_::_Mark {number} as spam_" : ["Oznacz {numer} jako spam","Oznacz {numer} jako spam","Oznacz {numer} jako spam","Oznacz {numer} jako spam"],
    "_Move {number} thread_::_Move {number} threads_" : ["Przenieś {number} wątek","Przenieś {number} wątki","Przenieś {number} wątków","Przenieś {number} wątków"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Przekaż {number} jako załącznik","Przekaż {number} jako załączniki","Przekaż {number} jako załączniki","Przekaż {number} jako załączniki"],
    "Report this bug" : "Zgłoś ten błąd",
    "All day" : "Cały dzień",
    "Select calendar" : "Wybierz kalendarz",
    "Description" : "Opis",
    "Create" : "Utwórz",
    "Event created" : "Utworzono wydarzenie",
    "Could not create event" : "Nie można utworzyć wydarzenia",
    "You accepted this invitation" : "Zaakceptowałeś to zaproszenie",
    "You tentatively accepted this invitation" : "Wstępnie zaakceptowałeś to zaproszenie",
    "You declined this invitation" : "Odrzuciłeś to zaproszenie",
    "You already reacted to this invitation" : "Już zareagowałeś na to zaproszenie",
    "You have been invited to an event" : "Zostałeś zaproszony na wydarzenie",
    "This event was cancelled" : "Wydarzenie te zostało odwołane",
    "Save to" : "Zapisz w",
    "Select" : "Zaznacz",
    "Comment" : "Komentarz",
    "Accept" : "Akceptuj",
    "Decline" : "Odrzuć",
    "Tentatively accept" : "Wstępnie zaakceptuj",
    "More options" : "Więcej opcji",
    "This event is in the past." : "To wydarzenie już minęło.",
    "This event was updated" : "Wydarzenie te zostało zaktualizowane",
    "{attendeeName} accepted your invitation" : "{attendeeName} przyjął Twoje zaproszenie",
    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} wstępnie zaakceptował Twoje zaproszenie",
    "{attendeeName} declined your invitation" : "{attendeeName} odrzucił Twoje zaproszenie",
    "{attendeeName} reacted to your invitation" : "{attendeeName} odpowiedział na Twoje zaproszenie",
    "Failed to save your participation status" : "Nie udało się zapisać Twojego statusu uczestnictwa",
    "domain" : "domena",
    "Remove" : "Usuń",
    "email" : "e-mail",
    "individual" : "indywidualny",
    "Itinerary for {type} is not supported yet" : "Trasa dla {type} nie jest jeszcze obsługiwana",
    "Could not open mailbox" : "Nie można otworzyć skrzynki pocztowej",
    "Loading messages …" : "Wczytywanie wiadomości…",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksowanie wiadomości. W przypadku większych skrzynek pocztowych może to potrwać trochę dłużej.",
    "Choose target mailbox" : "Wybierz docelową skrzynkę pocztową",
    "No more submailboxes in here" : "Nie ma więcej skrzynek podrzędnych",
    "Important info" : "Ważna informacja",
    "Other" : "Inne",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Wiadomości będą automatycznie oznaczane jako ważne na podstawie wiadomości, z którymi wchodziłeś w interakcję lub które oznaczałeś jako ważne. Na początku być może trzeba będzie ręcznie zmienić ważność dla uczenia systemu, ale z czasem będzie się poprawiać.",
    "The sender of this message has asked to be notified when you read this message." : "Nadawca tej wiadomości poprosił o powiadomienie o przeczytaniu tej wiadomości.",
    "Notify the sender" : "Powiadom nadawcę",
    "You sent a read confirmation to the sender of this message." : "Wysłałeś potwierdzenie do nadawcy o przeczytaniu tej wiadomości.",
    "Could not send mdn" : "Nie można wysłać mdn",
    "Forward" : "Przekaż dalej",
    "Move message" : "Przenieś wiadomość",
    "Translate" : "Tłumaczenie",
    "Forward message as attachment" : "Wyślij wiadomość jako załącznik",
    "View source" : "Pokaż źródło",
    "Download thread data for debugging" : "Pobierz dane wątku do debugowania",
    "Message body" : "Treść wiadomości",
    "Choose a folder to store the attachment in" : "Wybierz katalog, w którym chcesz zapisać załącznik",
    "Import into calendar" : "Importuj do kalendarza",
    "Download attachment" : "Pobierz załącznik",
    "Save to Files" : "Zapisz do Plików",
    "Unnamed" : "Bez nazwy",
    "Embedded message" : "Osadzona wiadomość",
    "View fewer attachments" : "Wyświetl mniej załączników",
    "Choose a folder to store the attachments in" : "Wybierz katalog do przechowywania załączników",
    "Save all to Files" : "Zapisz wszystko do Plików",
    "Download Zip" : "Pobierz Zip",
    "_View {count} more attachment_::_View {count} more attachments_" : ["Zobacz jeszcze {count} załącznik","Zobacz jeszcze {count} załączniki","Zobacz jeszcze {count} załączników","Zobacz jeszcze {count} załączników"],
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Ta wiadomość jest szyfrowana za pomocą PGP. Zainstaluj Mailvelope, aby ją odszyfrować.",
    "The images have been blocked to protect your privacy." : "Obrazy zostały zablokowane, aby chronić Twoją prywatność.",
    "Show images" : "Wyświetl obrazy",
    "Show images temporarily" : "Pokaż obrazy tymczasowo",
    "Always show images from {sender}" : "Zawsze pokazuj obrazy od {sender}",
    "Always show images from {domain}" : "Zawsze pokazuj obrazy z {domain}",
    "Message frame" : "Ramka wiadomości",
    "Quoted text" : "Cytowany tekst",
    "Move" : "Przenieś",
    "Moving" : "przenoszenie",
    "Moving thread" : "Przenoszenie wątku",
    "Moving message" : "Przenoszenie wiadomości",
    "Provisioned account is disabled" : "Zabezpieczone konto jest wyłączone",
    "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Zaloguj się przy użyciu hasła, aby włączyć to konto. Bieżąca sesja korzysta z uwierzytelniania bez hasła, m.in. SSO lub WebAuthn.",
    "Quota" : "Limit",
    "Show only subscribed mailboxes" : "Pokaż tylko subskrybowane skrzynki pocztowe",
    "Add mailbox" : "Dodaj skrzynkę pocztową",
    "Saving" : "Zapisywanie",
    "Move up" : "Przenieś wyżej",
    "Move down" : "Przenieś niżej",
    "Remove account" : "Usuń konto",
    "Loading …" : "Wczytywanie…",
    "Not supported by the server" : "Niewspierany przez serwer",
    "{usage} of {limit} used" : "Użyto {usage} z {limit}",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Konto dla {email} i zapisane w pamięci podręcznej dane e-mail zostaną usunięte z Nextcloud, ale pozostaną nadal u dostawcy poczty e-mail.",
    "Remove {email}" : "Usuń {email}",
    "Show all subscribed mailboxes" : "Pokaż wszystkie subskrybowane skrzynki pocztowe",
    "Show all mailboxes" : "Pokaż wszystkie skrzynki pocztowe",
    "Collapse mailboxes" : "Zwiń skrzynki pocztowe",
    "Mark all as read" : "Oznacz wszystkie jako przeczytane",
    "Mark all messages of this mailbox as read" : "Oznacz wszystkie wiadomości w tej skrzynce pocztowej jako przeczytane",
    "Add submailbox" : "Dodaj skrzynkę podrzędną",
    "Rename" : "Zmień nazwę",
    "Clear cache" : "Wyczyść pamięć podręczną",
    "Clear locally cached data, in case there are issues with synchronization." : "Wyczyść lokalnie buforowane dane, w przypadku problemów z synchronizacją.",
    "Subscribed" : "Zasubskrybowano",
    "Sync in background" : "Synchronizuj w tle",
    "Clear mailbox" : "Wyczyść skrzynkę pocztową",
    "Delete mailbox" : "Usuń skrzynkę pocztową",
    "All messages in mailbox will be deleted." : "Wszystkie wiadomości w skrzynce pocztowej zostaną usunięte.",
    "Clear mailbox {name}" : "Wyczyść skrzynkę pocztową {name}",
    "The mailbox and all messages in it will be deleted." : "Skrzynka pocztowa i wszystkie zawarte w niej wiadomości zostaną usunięte.",
    "Delete mailbox {name}" : "Usuń skrzynkę pocztową {name}",
    "An error occurred, unable to rename the mailbox." : "Wystąpił błąd, nie można zmienić nazwy skrzynki pocztowej.",
    "_{total} message_::_{total} messages_" : ["{total} wiadomość","{total} wiadomości","{total} wiadomości","{total} wiadomości"],
    "Outbox" : "Skrzynka nadawcza",
    "New message" : "Nowa wiadomość",
    "Error sending your message" : "Błąd podczas wysyłania wiadomości",
    "Retry" : "Powtórz",
    "Uploading attachments …" : "Wysyłanie załączników…",
    "Sending …" : "Wysyłanie…",
    "Warning sending your message" : "Ostrzeżenie podczas wysyłania wiadomości",
    "Send anyway" : "Wyślij mimo to",
    "Edit message" : "Edytuj wiadomość",
    "Draft" : "Wersja robocza",
    "Reply" : "Odpowiedz",
    "No sent mailbox configured. Please pick one in the account settings." : "Nie skonfigurowano żadnej skrzynki pocztowej dla wysyłanych wiadomości. Wybierz którąś w ustawieniach konta.",
    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Próbujesz wysłać do wielu odbiorców w Do i/lub DW. Rozważ użycie UDW, aby ukryć adresy odbiorców.",
    "Message discarded" : "Wiadomość odrzucona",
    "Could not discard message" : "Nie udało się odrzucić wiadomości",
    "Autoresponder off" : "Automatyczna wiadomość zwrotna wyłączona",
    "Autoresponder on" : "Automatyczna wiadomość zwrotna włączona",
    "First day" : "Pierwszy dzień",
    "Last day (optional)" : "Ostatni dzień (opcjonalnie)",
    "${subject} will be replaced with the subject of the message you are responding to" : "${subject} zostanie zastąpione tematem wiadomości, na którą odpowiadasz",
    "Message" : "Komunikat",
    "Oh Snap!" : "O rany!",
    "Save autoresponder" : "Zapisz automatyczną wiadomość zwrotną",
    "Could not open outbox" : "Nie udało się otworzyć skrzynki nadawczej",
    "Pending or not sent messages will show up here" : "Oczekujące lub niewysłane wiadomości pojawią się tutaj",
    "Message could not be sent" : "Nie można wysłać wiadomości",
    "Message deleted" : "Wiadomość usunięta",
    "Contacts with this address" : "Kontakty z adresem",
    "Add to Contact" : "Dodaj do kontaktu",
    "New Contact" : "Nowy kontakt",
    "Copy to clipboard" : "Kopiuj do schowka",
    "Contact name …" : "Nazwa kontaktu…",
    "Add" : "Dodaj",
    "Copied email address to clipboard" : "Skopiowano adres e-mail do schowka",
    "Could not copy email address to clipboard" : "Nie można skopiować adresu e-mail do schowka",
    "Show less" : "Pokaż mniej",
    "Show more" : "Pokaż więcej",
    "Search in mailbox" : "Szukaj w skrzynce pocztowej",
    "Close" : "Zamknij",
    "Search parameters" : "Wyszukaj parametry",
    "Body" : "Treść",
    "Date" : "Data",
    "Pick a start date" : "Wybierz datę rozpoczęcia",
    "Pick an end date" : "Wybierz datę zakończenia",
    "Tags" : "Etykiety",
    "Select tags" : "Wybierz etykiety",
    "Marked as" : "Oznaczono jako",
    "Has attachments" : "Posiada załączniki",
    "Last 7 days" : "Ostatnie 7 dni",
    "Clear" : "Wyczyść ",
    "Sieve Port" : "Port Sieve",
    "IMAP credentials" : "Poświadczenia IMAP",
    "Custom" : "Dowolnie",
    "Sieve User" : "Użytkownik Sieve",
    "Sieve Password" : "Hasło Sieve",
    "Save sieve settings" : "Zapisz ustawienia Sieve",
    "Save sieve script" : "Zapisz skrypt Sieve",
    "Signature …" : "Podpis…",
    "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Twój podpis jest większy niż 2 MB. Może to wpłynąć na wydajność Twojego edytora.",
    "Save signature" : "Zapisz podpis",
    "Place signature above quoted text" : "Umieść podpis nad cytowanym tekstem",
    "Saving new tag name …" : "Zapisywanie nowej nazwy etykiety…",
    "Delete tag" : "Usuń etykiety",
    "An error occurred, unable to rename the tag." : "Wystąpił błąd, nie można zmienić nazwy etykiety.",
    "Add default tags" : "Dodaj etykiety domyślne",
    "Add tag" : "Dodaj etykietę",
    "Saving tag …" : "Zapisywanie etykiety…",
    "Tag name is a hidden system tag" : "Nazwa etykiety jest ukrytej etykiety systemowej",
    "Tag already exists" : "Tag już istnieje",
    "An error occurred, unable to create the tag." : "Wystąpił błąd, nie można utworzyć etykiety.",
    "Loading thread" : "Wczytywanie wątku",
    "Not found" : "Nie znaleziono",
    "Could not load your message thread" : "Nie można wczytać wątku wiadomości",
    "The thread doesn't exist or has been deleted" : "Wątek nie istnieje lub został usunięty",
    "Unsubscribe" : "Wypisz się",
    "Reply all" : "Odpowiedz wszystkim",
    "Reply to sender only" : "Odpowiedz tylko nadawcy",
    "Mark as unfavorite" : "Oznacz jako nieulubione",
    "Mark as favorite" : "Oznacz jako nieulubione",
    "Mark as unread" : "Oznacz jako nieprzeczytane",
    "Mark as read" : "Oznacz jako przeczytane",
    "Archive message" : "Przenieś wiadomość do archiwum",
    "Delete message" : "Usuń wiadomość",
    "Message source" : "Źródło wiadomości",
    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Ta wiadomość zawiera zweryfikowany podpis cyfrowy S/MIME. Wiadomość nie została zmieniona od czasu jej wysłania.",
    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Ta wiadomość zawiera niezweryfikowany cyfrowy podpis S/MIME. Wiadomość mogła zostać zmieniona od czasu jej wysłania lub certyfikat osoby podpisującej jest niezaufany.",
    "Translate message" : "Przetłumacz wiadomość",
    "Source language to translate from" : "Język źródłowy, z którego chcesz tłumaczyć",
    "Translate from" : "Przetłumacz z",
    "Target language to translate into" : "Język docelowy, na który chcesz tłumaczyć",
    "Translate to" : "Przetłumacz na",
    "Translating" : "Tłumaczenie",
    "Copy translated text" : "Kopiuj przetłumaczony tekst",
    "The message could not be translated" : "Nie udało się przetłumaczyć wiadomości",
    "Translation copied to clipboard" : "Tłumaczenie skopiowane do schowka",
    "Translation could not be copied" : "Nie można skopiować tłumaczenia",
    "No senders are trusted at the moment." : "W tej chwili żaden nadawca nie jest zaufany.",
    "Could not remove trusted sender {sender}" : "Nie udało się usunąć zaufanego nadawcy {sender}",
    "(organizer)" : "(organizator)",
    "Untitled event" : "Wydarzenie bez tytułu",
    "Import into {calendar}" : "Importuj do {calendar}",
    "Event imported into {calendar}" : "Wydarzenie zaimportowane do {calendar}",
    "Airplane" : "Samolot",
    "Reservation {id}" : "Rezerwacja {id}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Lot {flightNr} z {depAirport} do {arrAirport}",
    "Train" : "Pociąg",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} z {depStation} do {arrStation}",
    "Train from {depStation} to {arrStation}" : "Pociąg z {depStation} do {arrStation}",
    "Flag" : "Flaga",
    "Operator" : "Operator",
    "Actions" : "Akcje",
    "New action" : "Nowa akcja",
    "Priority" : "Priorytet",
    "Mail app" : "Aplikacja poczty",
    "The mail app allows users to read mails on their IMAP accounts." : "Aplikacja poczty pozwala użytkownikom czytać wiadomości e-mail na kontach IMAP.",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Tutaj możesz znaleźć ustawienia dotyczące całej instancji. Ustawienia użytkownika można znaleźć w samej aplikacji (lewy dolny róg).",
    "Account provisioning" : "Zabezpieczanie konta",
    "A provisioning configuration will provision all accounts with a matching email address." : "Konfiguracja zabezpieczenia zapewni zabezpieczenie wszystkim kontom z pasujący adresem e-mail.",
    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "Użycie symbolu wieloznacznego (*) w polu domeny zabezpieczonej spowoduje utworzenie konfiguracji, która będzie obowiązywać wszystkich użytkowników, pod warunkiem, że nie odpowiadają one innej konfiguracji.",
    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "Mechanizm zabezpieczenia będzie nadawać priorytet konkretnym konfiguracjom domeny w stosunku do konfiguracji domeny z symbolem wieloznacznym.",
    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "Jeśli zostanie znaleziona nowa pasująca konfiguracja po tym, jak użytkownik zabezpieczył już inną konfiguracją, to nowa konfiguracja będzie miała pierwszeństwo oraz użytkownik zostanie ponownie zabezpieczony tą konfiguracją.",
    "There can only be one configuration per domain and only one wildcard domain configuration." : "W każdej domenie może być tylko jedna konfiguracja i tylko jedna konfiguracja domeny z symbolem wieloznacznym.",
    "These settings can be used in conjunction with each other." : "Te ustawienia mogą być używane w połączeniu ze sobą.",
    "If you only want to provision one domain for all users, use the wildcard (*)." : "Jeśli chcesz zabezpieczyć tylko jedną domenę wszystkim użytkownikom, użyj symbolu wieloznacznego (*).",
    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "Ustawienie ma największy sens tylko wtedy, gdy używasz tego samego zaplecza użytkownika na serwerze Nextcloud i serwerze pocztowym swojej organizacji.",
    "Provisioning Configurations" : "Konfiguracje zabezpieczenia",
    "Add new config" : "Dodaj nową konfigurację",
    "Provision all accounts" : "Zabezpiecz wszystkie konta",
    "Allow additional mail accounts" : "Zezwalaj na dodatkowe konta pocztowe",
    "Allow additional Mail accounts from User Settings" : "Zezwalaj na dodatkowe konta pocztowe w Ustawieniach użytkownika",
    "Anti Spam Service" : "Usługa antyspamowa",
    "You can set up an anti spam service email address here." : "Tutaj możesz ustawić adres e-mail usługi antyspamowej.",
    "Any email that is marked as spam will be sent to the anti spam service." : "Każdy e-mail oznaczony jako spam zostanie wysłany do usługi antyspamowej.",
    "Gmail integration" : "Integracja z Gmailem",
    "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmail umożliwia użytkownikom dostęp do poczty e-mail za pośrednictwem protokołu IMAP. Ze względów bezpieczeństwa dostęp ten jest możliwy tylko za pomocą połączenia OAuth 2.0 lub kont Google korzystających z uwierzytelniania dwuskładnikowego i haseł do aplikacji.",
    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "Musisz zarejestrować nowy ID klienta dla \"Aplikacji internetowej\" w konsoli Google Cloud. Dodaj adres URL {url} jako identyfikator URI autoryzowanego przekierowania.",
    "Microsoft integration" : "Integracja Microsoft",
    "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "Firma Microsoft umożliwia użytkownikom dostęp do poczty e-mail za pośrednictwem protokołu IMAP. Ze względów bezpieczeństwa dostęp ten jest możliwy tylko przy połączeniu OAuth 2.0.",
    "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "Musisz zarejestrować nową aplikację w portalu Microsoft Azure Active Directory. Dodaj adres URL {url} jako URI przekierowania.",
    "Successfully updated config for \"{domain}\"" : "Pomyślnie zaktualizowano konfigurację dla \"{domain}\"",
    "Error saving config" : "Błąd podczas zapisywania konfiguracji",
    "Saved config for \"{domain}\"" : "Zapisana konfiguracja dla \"{domain}\"",
    "Could not save provisioning setting" : "Nie udało się zapisać ustawienia zabezpieczenia",
    "There was an error when provisioning accounts." : "Wystąpił błąd podczas zabezpieczania kont.",
    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "Pomyślnie usunięto i wyczyszczono zabezpieczenie kont dla domeny \"{domain}\"",
    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Błąd podczas usuwania i czyszczenia zabezpieczenia kont dla domeny \"{domain}\"",
    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["Pomyślnie zabezpieczono {count} konto.","Pomyślnie zabezpieczono {count} konta.","Pomyślnie zabezpieczono {count} kont.","Pomyślnie zabezpieczono {count} kont."],
    "Anti Spam" : "Antyspam",
    "Add the email address of your anti spam report service here." : "Dodaj tutaj adres e-mail usługi raportowania antyspamowego.",
    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "W przypadku korzystania z tego ustawienia e-mail z raportem zostanie wysłany do serwera zgłaszania spamu, gdy użytkownik kliknie opcję \"Oznacz jako spam\".",
    "The original message will be attached as a \"message/rfc822\" attachment." : "Oryginalna wiadomość zostanie dołączona jako załącznik \"message/rfc822\".",
    "\"Mark as Spam\" Email Address" : "Adres e-mail \"Oznacz jako spam\"",
    "\"Mark Not Junk\" Email Address" : "Adres e-mail \"Oznacz jako nie spam\"",
    "Reset" : "Resetuj",
    "Successfully set up anti spam email addresses" : "Pomyślnie skonfigurowane antyspamowe adresy e-mail",
    "Error saving anti spam email addresses" : "Błąd podczas zapisywania antyspamowych adresów e-mail",
    "Successfully deleted anti spam reporting email" : "Pomyślnie usunięto e-mail z raportami antyspamowymi",
    "Error deleting anti spam reporting email" : "Błąd podczas usuwania e-maila z raportami antyspamowymi",
    "Client ID" : "ID klienta",
    "Client secret" : "Tajny klucz klienta",
    "Unlink" : "Odłącz",
    "Google integration configured" : "Skonfigurowano integrację Google",
    "Could not configure Google integration" : "Nie można skonfigurować integracji Google",
    "Google integration unlinked" : "Odłączono integrację z Google",
    "Could not unlink Google integration" : "Nie można odłączyć integracji Google",
    "Tenant ID (optional)" : "ID najemcy (opcjonalnie)",
    "Microsoft integration configured" : "Skonfigurowano integrację Microsoft",
    "Could not configure Microsoft integration" : "Nie można skonfigurować integracji Microsoft",
    "Microsoft integration unlinked" : "Odłączono integrację Microsoft",
    "Could not unlink Microsoft integration" : "Nie można odłączyć integracji Microsoft",
    "Domain Match: {provisioningDomain}" : "Dopasowanie domeny: {provisioningDomain}",
    "Email: {email}" : "E-mail: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} na {host}:{port} (szyfrowanie {ssl})",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} na {host}:{port} (szyfrowanie {ssl})",
    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} na {host}:{port} (szyfrowanie {ssl})",
    "Configuration for \"{provisioningDomain}\"" : "Konfiguracja dla \"{provisioningDomain}\"",
    "Provisioning domain" : "Zabezpieczenie domeny",
    "Email address template" : "Szablon adresu e-mail",
    "IMAP" : "IMAP",
    "User" : "Użytkownik",
    "Host" : "Host",
    "Port" : "Port",
    "SMTP" : "SMTP",
    "Sieve" : "Sieve",
    "Enable sieve integration" : "Włącz integrację Sieve",
    "LDAP aliases integration" : "Integracja aliasów LDAP",
    "Enable LDAP aliases integration" : "Włącz integrację aliasów LDAP",
    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "Integracja aliasów LDAP odczytuje atrybut ze skonfigurowanego katalogu LDAP w celu zabezpieczenia aliasów e-mail.",
    "LDAP attribute for aliases" : "Atrybut LDAP dla aliasów",
    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "Atrybut wielowartościowy do zabezpieczenia aliasów e-mail. Dla każdej wartości tworzony jest alias. Aliasy istniejące w Nextcloud, których nie ma w katalogu LDAP, są usuwane.",
    "Save Config" : "Zapisz konfigurację",
    "Unprovision & Delete Config" : "Cofnij zabezpieczenie i usuń konfigurację",
    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% i %EMAIL% zostaną zastąpione UID i adresem e-mail użytkownika",
    "With the settings above, the app will create account settings in the following way:" : "Przy powyższych ustawieniach aplikacja utworzy ustawienia konta w następujący sposób:",
    "S/MIME certificates" : "Certyfikaty S/MIME",
    "Certificate name" : "Nazwa certyfikatu",
    "E-mail address" : "Adres e-mail",
    "Valid until" : "Ważny do",
    "Import certificate" : "Importuj certyfikat",
    "Import S/MIME certificate" : "Importuj certyfikat S/MIME",
    "Certificate" : "Certyfikat",
    "Submit" : "Wyślij",
    "Certificate imported successfully" : "Certyfikat został zaimportowany pomyślnie",
    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Nie udało się zaimportować certyfikatu. Upewnij się, że klucz prywatny jest zgodny z certyfikatem i nie jest chroniony hasłem.",
    "Failed to import the certificate" : "Nie udało się zaimportować certyfikatu",
    "Account connected" : "Połączono z kontem",
    "You can close this window" : "Możesz zamknąć okno",
    "Connect your mail account" : "Podłącz konto pocztowe",
    "To add a mail account, please contact your administrator." : "Aby dodać konto pocztowe, skontaktuj się z administratorem.",
    "Next week – {timeLocale}" : "Następny tydzień – {timeLocale}",
    "This weekend – {timeLocale}" : "W ten weekend – {timeLocale}",
    "Tomorrow – {timeLocale}" : "Jutro – {timeLocale}",
    "Later today – {timeLocale}" : "Później dzisiaj – {timeLocale}",
    "All" : "Wszystko",
    "Drafts" : "Wersje robocze",
    "Favorites" : "Ulubione",
    "Priority inbox" : "Priorytet skrzynki odbiorczej",
    "All inboxes" : "Wszystkie skrzynki odbiorcze",
    "Inbox" : "Skrzynka odbiorcza",
    "Junk" : "Spam",
    "Sent" : "Wysłane",
    "Trash" : "Kosz",
    "Connect OAUTH2 account" : "Połącz konto OAUTH2",
    "Error while sharing file" : "Błąd podczas udostępniania pliku",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nowa wiadomość\nod {from}","%n nowe wiadomości \nod {from}","%n nowych wiadomości \nod {from}","%n nowych wiadomości \nod {from}"],
    "Nextcloud Mail" : "Poczta Nextcloud",
    "Attachments were not copied. Please add them manually." : "Załączniki nie zostały skopiowane. Dodaj je ręcznie.",
    "Message sent" : "Wiadomość wysłana",
    "Could not send message" : "Nie udało się wysłać wiadomości",
    "Could not load {tag}{name}{endtag}" : "Nie można załadować {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Wystąpił problem podczas ładowania {tag}{name}{endtag}",
    "Could not load your message" : "Nie można wczytać wiadomości",
    "Could not load the desired message" : "Nie można wczytać żądanej wiadomości",
    "Could not load the message" : "Nie można wczytać wiadomości",
    "Error loading message" : "Błąd podczas wczytywania wiadomości",
    "Forwarding to %s" : "Przekierowanie do %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Kliknij tutaj, jeśli nie zostaniesz automatycznie przekierowany w ciągu kilku sekund.",
    "Redirect" : "Przekieruj",
    "The link leads to %s" : "Link prowadzi do %s",
    "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Jeśli nie chcesz odwiedzić tej strony, możesz powrócić do <a href=\"%s\">Poczty</a>.",
    "Continue to %s" : "Kontynuuj do %s",
    "Unselect" : "Odznacz"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
